# DomiKnowS

This library provides a language interface integrate Domain Knowldge in Deep Learning. It helps specify a problem domain with a conceptual graph including declarations of edges and nodes, as well as any global logical constraints on the graph, against which neural network outputs bounded to the graph can be evaluated.
This adds a relational overlay over elements in a network that relates physical concepts in applications.

Please refer to our [documentation](docs) for further details.

Please visit the DomiKnows Webpage for more information and getting to start documentations. 
[Link to the DomiKnows Website](https://hlr.github.io/domiknows-nlp/)

## Related

The project is inspired by [DeLBP (Declarative Learning based Programming)](http://www.cs.tulane.edu/~pkordjam/delbp.htm),
closely related to [Saul programing language](https://github.com/HLR/HetSaul).
[Workshop of DeLBP](http://delbp.github.io/) is held annually to communicate the idea about combining learning models with declarative programming or reasoning.
[DeLBP 2019](http://delbp.github.io/) will be held in conjunction with IJCAI-2019, August 10-16, 2019, Macao, China.
At a wider scope, the project is related to [OntologyBasedLearning](https://github.com/HLR/OntologyBasedLearning), which can provide a source of domain knowledge as the graph (ontology) in this project.
